==> ejc-bid-api-3.0.0-20211118.091341-11-sources.jar: com/ejianc/business/bid/vo/BiddingFileReviewVO.java <==
package com.ejianc.business.bid.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 招标文件评审
 * 
 * @author generator
 * 
 */
public class BiddingFileReviewVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态
    private Long engineeringId; // 工程名称
    private String engineeringCode; // 工程编码
    private String engineeringName; // 工程名称
    private Long followCompanyId; // 跟踪单位
    private String followCompanyName; // 跟踪单位名称
    private java.util.Date reviewDate; // 评审日期
    private String builtConstructor; // 建造师
    private Long responsiblePersonId; // 项目负责人
    private String responsiblePersonName; // 项目负责人名称
    private java.math.BigDecimal builtArea; // 建筑面积
    private Long bidEvaluation; // 评标办法
    private String bidEvaluationName; // 评标办法内容
    private Integer quotationForm; // 报价形式
    private String quotationFormInfo; // 报价形式内容
    private Long area; // 地区
    private String areaInfo; // 地区内容
    private String address; // 工程地点
    private String buildCompanyCode; // 建设单位
    private String buildCompanyName; // 建设单位名称
    private String buildCompanyNature; // 建设单位性质
    private String ownerClientName; // 业主委托人名称
    private String ownerClientPhone; // 业主委托人电话
    private String investor; // 投资主体
    private String fundsSource; // 资金来源
    private java.math.BigDecimal fundsQuota; // 投资额
    private java.math.BigDecimal fundsRate; // 投资费率
    private Long biddingForm; // 招标形式
    private String projectQuality; // 工程质量
    private String bidRange; // 投标范围
    private java.util.Date plannedTenderDate; // 预计招标日期
    private java.util.Date plannedCommencementDate; // 预计开工日期
    private java.util.Date plannedFinishDate; // 计划竣工日期
    private java.math.BigDecimal planDay; // 计划工期天数
    private Long engineeringType; // 工程类型
    private String engineeringTypeName; // 工程类型名称
    private String biddingAgency; // 招标代理机构
    private String reviewInfo; // 评审内容
    private String remark; // 备注信息
    private Long orgId; // 组织ID
    private String orgName; // 组织名称
    private Long enrollId; // 报名ID
    private Integer isStop; // 是否中止
    private Long employeeId; // 编制人
    private String employeeName; // 编制人
    private java.util.Date billDate; // 编制日期
    private Long makeOrgId; // 编制机构
    private String makeOrgName; // 编制机构
    

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 工程名称
     */
    public Long getEngineeringId() {
        return engineeringId;
    }

    /**
     * 工程名称
     */
    public void setEngineeringId(Long engineeringId) {
        this.engineeringId = engineeringId;
    }
    /**
     * 工程编码
     */
    public String getEngineeringCode() {
        return engineeringCode;
    }

    /**
     * 工程编码
     */
    public void setEngineeringCode(String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    /**
     * 工程名称
     */
    public String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 跟踪单位
     */
    public Long getFollowCompanyId() {
        return followCompanyId;
    }

    /**
     * 跟踪单位
     */
    public void setFollowCompanyId(Long followCompanyId) {
        this.followCompanyId = followCompanyId;
    }
    /**
     * 跟踪单位名称
     */
    public String getFollowCompanyName() {
        return followCompanyName;
    }

    /**
     * 跟踪单位名称
     */
    public void setFollowCompanyName(String followCompanyName) {
        this.followCompanyName = followCompanyName;
    }
    /**
     * 评审日期
     */
    public java.util.Date getReviewDate() {
        return reviewDate;
    }

    /**
     * 评审日期
     */
    public void setReviewDate(java.util.Date reviewDate) {
        this.reviewDate = reviewDate;
    }
    /**
     * 建造师
     */
    public String getBuiltConstructor() {
        return builtConstructor;
    }

    /**
     * 建造师
     */
    public void setBuiltConstructor(String builtConstructor) {
        this.builtConstructor = builtConstructor;
    }
    /**
     * 项目负责人
     */
    public Long getResponsiblePersonId() {
        return responsiblePersonId;
    }

    /**
     * 项目负责人
     */
    public void setResponsiblePersonId(Long responsiblePersonId) {
        this.responsiblePersonId = responsiblePersonId;
    }
    /**
     * 项目负责人名称
     */
    public String getResponsiblePersonName() {
        return responsiblePersonName;
    }

    /**
     * 项目负责人名称
     */
    public void setResponsiblePersonName(String responsiblePersonName) {
        this.responsiblePersonName = responsiblePersonName;
    }
    /**
     * 建筑面积
     */
    public java.math.BigDecimal getBuiltArea() {
        return builtArea;
    }

    /**
     * 建筑面积
     */
    public void setBuiltArea(java.math.BigDecimal builtArea) {
        this.builtArea = builtArea;
    }
    /**
     * 评标办法
     */
    public Long getBidEvaluation() {
        return bidEvaluation;
    }

    /**
     * 评标办法
     */
    public void setBidEvaluation(Long bidEvaluation) {
        this.bidEvaluation = bidEvaluation;
    }
    /**
     * 评标办法内容
     */
    public String getBidEvaluationName() {
        return bidEvaluationName;
    }

    /**
     * 评标办法内容
     */
    public void setBidEvaluationName(String bidEvaluationName) {
        this.bidEvaluationName = bidEvaluationName;
    }
    /**
     * 报价形式
     */
    public Integer getQuotationForm() {
        return quotationForm;
    }

    /**
     * 报价形式
     */
    public void setQuotationForm(Integer quotationForm) {
        this.quotationForm = quotationForm;
    }
    /**
     * 报价形式内容
     */
    public String getQuotationFormInfo() {
        return quotationFormInfo;
    }

    /**
     * 报价形式内容
     */
    public void setQuotationFormInfo(String quotationFormInfo) {
        this.quotationFormInfo = quotationFormInfo;
    }
    /**
     * 地区
     */
    public Long getArea() {
        return area;
    }

    /**
     * 地区
     */
    public void setArea(Long area) {
        this.area = area;
    }
    /**
     * 地区内容
     */
    public String getAreaInfo() {
        return areaInfo;
    }

    /**
     * 地区内容
     */
    public void setAreaInfo(String areaInfo) {
        this.areaInfo = areaInfo;
    }
    /**
     * 工程地点
     */
    public String getAddress() {
        return address;
    }

    /**
     * 工程地点
     */
    public void setAddress(String address) {
        this.address = address;
    }
    /**
     * 建设单位
     */
    public String getBuildCompanyCode() {
        return buildCompanyCode;
    }

    /**
     * 建设单位
     */
    public void setBuildCompanyCode(String buildCompanyCode) {
        this.buildCompanyCode = buildCompanyCode;
    }
    /**
     * 建设单位名称
     */
    public String getBuildCompanyName() {
        return buildCompanyName;
    }

    /**
     * 建设单位名称
     */
    public void setBuildCompanyName(String buildCompanyName) {
        this.buildCompanyName = buildCompanyName;
    }
    /**
     * 建设单位性质
     */
    public String getBuildCompanyNature() {
        return buildCompanyNature;
    }

    /**
     * 建设单位性质
     */
    public void setBuildCompanyNature(String buildCompanyNature) {
        this.buildCompanyNature = buildCompanyNature;
    }
    /**
     * 业主委托人名称
     */
    public String getOwnerClientName() {
        return ownerClientName;
    }

    /**
     * 业主委托人名称
     */
    public void setOwnerClientName(String ownerClientName) {
        this.ownerClientName = ownerClientName;
    }
    /**
     * 业主委托人电话
     */
    public String getOwnerClientPhone() {
        return ownerClientPhone;
    }

    /**
     * 业主委托人电话
     */
    public void setOwnerClientPhone(String ownerClientPhone) {
        this.ownerClientPhone = ownerClientPhone;
    }
    /**
     * 投资主体
     */
    public String getInvestor() {
        return investor;
    }

    /**
     * 投资主体
     */
    public void setInvestor(String investor) {
        this.investor = investor;
    }
    /**
     * 资金来源
     */
    public String getFundsSource() {
        return fundsSource;
    }

    /**
     * 资金来源
     */
    public void setFundsSource(String fundsSource) {
        this.fundsSource = fundsSource;
    }
    /**
     * 投资额
     */
    public java.math.BigDecimal getFundsQuota() {
        return fundsQuota;
    }

    /**
     * 投资额
     */
    public void setFundsQuota(java.math.BigDecimal fundsQuota) {
        this.fundsQuota = fundsQuota;
    }
    /**
     * 投资费率
     */
    public java.math.BigDecimal getFundsRate() {
        return fundsRate;
    }

    /**
     * 投资费率
     */
    public void setFundsRate(java.math.BigDecimal fundsRate) {
        this.fundsRate = fundsRate;
    }
    /**
     * 招标形式
     */
    public Long getBiddingForm() {
        return biddingForm;
    }

    /**
     * 招标形式
     */
    public void setBiddingForm(Long biddingForm) {
        this.biddingForm = biddingForm;
    }
    /**
     * 工程质量
     */
    public String getProjectQuality() {
        return projectQuality;
    }

    /**
     * 工程质量
     */
    public void setProjectQuality(String projectQuality) {
        this.projectQuality = projectQuality;
    }
    /**
     * 投标范围
     */
    public String getBidRange() {
        return bidRange;
    }

    /**
     * 投标范围
     */
    public void setBidRange(String bidRange) {
        this.bidRange = bidRange;
    }
    /**
     * 预计招标日期
     */
    public java.util.Date getPlannedTenderDate() {
        return plannedTenderDate;
    }

    /**
     * 预计招标日期
     */
    public void setPlannedTenderDate(java.util.Date plannedTenderDate) {
        this.plannedTenderDate = plannedTenderDate;
    }
    /**
     * 预计开工日期
     */
    public java.util.Date getPlannedCommencementDate() {
        return plannedCommencementDate;
    }

    /**
     * 预计开工日期
     */
    public void setPlannedCommencementDate(java.util.Date plannedCommencementDate) {
        this.plannedCommencementDate = plannedCommencementDate;
    }
    /**
     * 计划竣工日期
     */
    public java.util.Date getPlannedFinishDate() {
        return plannedFinishDate;
    }

    /**
     * 计划竣工日期
     */
    public void setPlannedFinishDate(java.util.Date plannedFinishDate) {
        this.plannedFinishDate = plannedFinishDate;
    }
    /**
     * 计划工期天数
     */
    public java.math.BigDecimal getPlanDay() {
        return planDay;
    }

    /**
     * 计划工期天数
     */
    public void setPlanDay(java.math.BigDecimal planDay) {
        this.planDay = planDay;
    }
    /**
     * 工程类型
     */
    public Long getEngineeringType() {
        return engineeringType;
    }

    /**
     * 工程类型
     */
    public void setEngineeringType(Long engineeringType) {
        this.engineeringType = engineeringType;
    }
    /**
     * 工程类型名称
     */
    public String getEngineeringTypeName() {
        return engineeringTypeName;
    }

    /**
     * 工程类型名称
     */
    public void setEngineeringTypeName(String engineeringTypeName) {
        this.engineeringTypeName = engineeringTypeName;
    }
    /**
     * 招标代理机构
     */
    public String getBiddingAgency() {
        return biddingAgency;
    }

    /**
     * 招标代理机构
     */
    public void setBiddingAgency(String biddingAgency) {
        this.biddingAgency = biddingAgency;
    }
    /**
     * 评审内容
     */
    public String getReviewInfo() {
        return reviewInfo;
    }

    /**
     * 评审内容
     */
    public void setReviewInfo(String reviewInfo) {
        this.reviewInfo = reviewInfo;
    }
    /**
     * 备注信息
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注信息
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织ID
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织ID
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 报名ID
     */
    public Long getEnrollId() {
        return enrollId;
    }

    /**
     * 报名ID
     */
    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }
    /**
     * 是否中止
     */
    public Integer getIsStop() {
        return isStop;
    }

    /**
     * 是否中止
     */
    public void setIsStop(Integer isStop) {
        this.isStop = isStop;
    }
    /**
     * 编制人
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 编制人
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 编制人
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 编制人
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 编制日期
     */
    public java.util.Date getBillDate() {
        return billDate;
    }

    /**
     * 编制日期
     */
    public void setBillDate(java.util.Date billDate) {
        this.billDate = billDate;
    }
    /**
     * 编制机构
     */
    public Long getMakeOrgId() {
        return makeOrgId;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgId(Long makeOrgId) {
        this.makeOrgId = makeOrgId;
    }
    /**
     * 编制机构
     */
    public String getMakeOrgName() {
        return makeOrgName;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgName(String makeOrgName) {
        this.makeOrgName = makeOrgName;
    }
    
}

==> ejc-bid-api-3.0.0-20211119.033937-13-sources.jar: com/ejianc/business/bid/vo/BiddingFileReviewVO.java <==
package com.ejianc.business.bid.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 招标文件评审
 * 
 * @author generator
 * 
 */
public class BiddingFileReviewVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态
    private Long engineeringId; // 工程名称
    private String engineeringCode; // 工程编码
    private String engineeringName; // 工程名称
    private Long followCompanyId; // 跟踪单位
    private String followCompanyName; // 跟踪单位名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date reviewDate; // 评审日期
    private String builtConstructor; // 建造师
    private Long responsiblePersonId; // 项目负责人
    private String responsiblePersonName; // 项目负责人名称
    private java.math.BigDecimal builtArea; // 建筑面积
    private Long bidEvaluation; // 评标办法
    private String bidEvaluationName; // 评标办法内容
    private Integer quotationForm; // 报价形式
    private String quotationFormInfo; // 报价形式内容
    private String area; // 地区
    private java.lang.String province; // 省份
    private java.lang.String city; // 城市
    private java.lang.String region; // 区县
    private java.lang.String adcode; // 邮编
    private String address; // 工程地点
    private Long buildCompanyCode; // 建设单位
    private String buildCompanyName; // 建设单位名称
    private String buildCompanyNature; // 建设单位性质
    private String ownerClientName; // 业主委托人名称
    private String ownerClientPhone; // 业主委托人电话
    private String investor; // 投资主体
    private String fundsSource; // 资金来源
    private java.math.BigDecimal fundsQuota; // 投资额
    private java.math.BigDecimal fundsRate; // 投资费率
    private String biddingForm; // 招标形式
    private String projectQuality; // 工程质量
    private String bidRange; // 投标范围
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date plannedTenderDate; // 预计招标日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date plannedCommencementDate; // 预计开工日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date plannedFinishDate; // 计划竣工日期
    private java.math.BigDecimal planDay; // 计划工期天数
    private Long engineeringType; // 工程类型
    private String engineeringTypeName; // 工程类型名称
    private String biddingAgency; // 招标代理机构
    private String reviewInfo; // 评审内容
    private String remark; // 备注信息
    private Long orgId; // 组织ID
    private String orgName; // 组织名称
    private Long enrollId; // 报名ID
    private Integer isStop; // 是否中止
    private Long employeeId; // 编制人
    private String employeeName; // 编制人
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date billDate; // 编制日期
    private Long makeOrgId; // 编制机构
    private String makeOrgName; // 编制机构
    

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 工程名称
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public Long getEngineeringId() {
        return engineeringId;
    }

    /**
     * 工程名称
     */
    @ReferDeserialTransfer
    public void setEngineeringId(Long engineeringId) {
        this.engineeringId = engineeringId;
    }
    /**
     * 工程编码
     */
    public String getEngineeringCode() {
        return engineeringCode;
    }

    /**
     * 工程编码
     */
    public void setEngineeringCode(String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    /**
     * 工程名称
     */
    public String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 跟踪单位
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public Long getFollowCompanyId() {
        return followCompanyId;
    }
    /**
     * 跟踪单位
     */
    @ReferDeserialTransfer
    public void setFollowCompanyId(Long followCompanyId) {
        this.followCompanyId = followCompanyId;
    }
    /**
     * 跟踪单位名称
     */
    public String getFollowCompanyName() {
        return followCompanyName;
    }

    /**
     * 跟踪单位名称
     */
    public void setFollowCompanyName(String followCompanyName) {
        this.followCompanyName = followCompanyName;
    }
    /**
     * 评审日期
     */
    public java.util.Date getReviewDate() {
        return reviewDate;
    }

    /**
     * 评审日期
     */
    public void setReviewDate(java.util.Date reviewDate) {
        this.reviewDate = reviewDate;
    }
    /**
     * 建造师
     */
    public String getBuiltConstructor() {
        return builtConstructor;
    }

    /**
     * 建造师
     */
    public void setBuiltConstructor(String builtConstructor) {
        this.builtConstructor = builtConstructor;
    }
    /**
     * 项目负责人
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public Long getResponsiblePersonId() {
        return responsiblePersonId;
    }

    /**
     * 项目负责人
     */
    @ReferDeserialTransfer
    public void setResponsiblePersonId(Long responsiblePersonId) {
        this.responsiblePersonId = responsiblePersonId;
    }
    /**
     * 项目负责人名称
     */
    public String getResponsiblePersonName() {
        return responsiblePersonName;
    }

    /**
     * 项目负责人名称
     */
    public void setResponsiblePersonName(String responsiblePersonName) {
        this.responsiblePersonName = responsiblePersonName;
    }
    /**
     * 建筑面积
     */
    public java.math.BigDecimal getBuiltArea() {
        return builtArea;
    }

    /**
     * 建筑面积
     */
    public void setBuiltArea(java.math.BigDecimal builtArea) {
        this.builtArea = builtArea;
    }
    /**
     * 评标办法
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public Long getBidEvaluation() {
        return bidEvaluation;
    }

    /**
     * 评标办法
     */
    @ReferDeserialTransfer
    public void setBidEvaluation(Long bidEvaluation) {
        this.bidEvaluation = bidEvaluation;
    }
    /**
     * 评标办法内容
     */
    public String getBidEvaluationName() {
        return bidEvaluationName;
    }

    /**
     * 评标办法内容
     */
    public void setBidEvaluationName(String bidEvaluationName) {
        this.bidEvaluationName = bidEvaluationName;
    }
    /**
     * 报价形式
     */
    public Integer getQuotationForm() {
        return quotationForm;
    }

    /**
     * 报价形式
     */
    public void setQuotationForm(Integer quotationForm) {
        this.quotationForm = quotationForm;
    }
    /**
     * 报价形式内容
     */
    public String getQuotationFormInfo() {
        return quotationFormInfo;
    }

    /**
     * 报价形式内容
     */
    public void setQuotationFormInfo(String quotationFormInfo) {
        this.quotationFormInfo = quotationFormInfo;
    }
    /**
     * 地区
     */
    public String getArea() {
        return area;
    }
    /**
     * 地区
     */
    public void setArea(String area) {
        this.area = area;
    }
    /**
     * 省份
     */
    public String getProvince() {
        return province;
    }
    /**
     * 省份
     */
    public void setProvince(String province) {
        this.province = province;
    }
    /**
     * 城市
     */
    public String getCity() {
        return city;
    }
    /**
     * 城市
     */
    public void setCity(String city) {
        this.city = city;
    }
    /**
     * 区县
     */
    public String getRegion() {
        return region;
    }
    /**
     * 区县
     */
    public void setRegion(String region) {
        this.region = region;
    }
    /**
     * 邮编
     */
    public String getAdcode() {
        return adcode;
    }
    /**
     * 邮编
     */
    public void setAdcode(String adcode) {
        this.adcode = adcode;
    }

    /**
     * 工程地点
     */
    public String getAddress() {
        return address;
    }

    /**
     * 工程地点
     */
    public void setAddress(String address) {
        this.address = address;
    }
    /**
     * 建设单位
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public Long getBuildCompanyCode() {
        return buildCompanyCode;
    }

    /**
     * 建设单位
     */
    @ReferDeserialTransfer
    public void setBuildCompanyCode(Long buildCompanyCode) {
        this.buildCompanyCode = buildCompanyCode;
    }
    /**
     * 建设单位名称
     */
    public String getBuildCompanyName() {
        return buildCompanyName;
    }

    /**
     * 建设单位名称
     */
    public void setBuildCompanyName(String buildCompanyName) {
        this.buildCompanyName = buildCompanyName;
    }
    /**
     * 建设单位性质
     */
    public String getBuildCompanyNature() {
        return buildCompanyNature;
    }

    /**
     * 建设单位性质
     */
    public void setBuildCompanyNature(String buildCompanyNature) {
        this.buildCompanyNature = buildCompanyNature;
    }
    /**
     * 业主委托人名称
     */
    public String getOwnerClientName() {
        return ownerClientName;
    }

    /**
     * 业主委托人名称
     */
    public void setOwnerClientName(String ownerClientName) {
        this.ownerClientName = ownerClientName;
    }
    /**
     * 业主委托人电话
     */
    public String getOwnerClientPhone() {
        return ownerClientPhone;
    }

    /**
     * 业主委托人电话
     */
    public void setOwnerClientPhone(String ownerClientPhone) {
        this.ownerClientPhone = ownerClientPhone;
    }
    /**
     * 投资主体
     */
    public String getInvestor() {
        return investor;
    }

    /**
     * 投资主体
     */
    public void setInvestor(String investor) {
        this.investor = investor;
    }
    /**
     * 资金来源
     */
    public String getFundsSource() {
        return fundsSource;
    }

    /**
     * 资金来源
     */
    public void setFundsSource(String fundsSource) {
        this.fundsSource = fundsSource;
    }
    /**
     * 投资额
     */
    public java.math.BigDecimal getFundsQuota() {
        return fundsQuota;
    }

    /**
     * 投资额
     */
    public void setFundsQuota(java.math.BigDecimal fundsQuota) {
        this.fundsQuota = fundsQuota;
    }
    /**
     * 投资费率
     */
    public java.math.BigDecimal getFundsRate() {
        return fundsRate;
    }

    /**
     * 投资费率
     */
    public void setFundsRate(java.math.BigDecimal fundsRate) {
        this.fundsRate = fundsRate;
    }
    /**
     * 招标形式
     */
    public String getBiddingForm() {
        return biddingForm;
    }

    /**
     * 招标形式
     */
    public void setBiddingForm(String biddingForm) {
        this.biddingForm = biddingForm;
    }
    /**
     * 工程质量
     */
    public String getProjectQuality() {
        return projectQuality;
    }

    /**
     * 工程质量
     */
    public void setProjectQuality(String projectQuality) {
        this.projectQuality = projectQuality;
    }
    /**
     * 投标范围
     */
    public String getBidRange() {
        return bidRange;
    }

    /**
     * 投标范围
     */
    public void setBidRange(String bidRange) {
        this.bidRange = bidRange;
    }
    /**
     * 预计招标日期
     */
    public java.util.Date getPlannedTenderDate() {
        return plannedTenderDate;
    }

    /**
     * 预计招标日期
     */
    public void setPlannedTenderDate(java.util.Date plannedTenderDate) {
        this.plannedTenderDate = plannedTenderDate;
    }
    /**
     * 预计开工日期
     */
    public java.util.Date getPlannedCommencementDate() {
        return plannedCommencementDate;
    }

    /**
     * 预计开工日期
     */
    public void setPlannedCommencementDate(java.util.Date plannedCommencementDate) {
        this.plannedCommencementDate = plannedCommencementDate;
    }
    /**
     * 计划竣工日期
     */
    public java.util.Date getPlannedFinishDate() {
        return plannedFinishDate;
    }

    /**
     * 计划竣工日期
     */
    public void setPlannedFinishDate(java.util.Date plannedFinishDate) {
        this.plannedFinishDate = plannedFinishDate;
    }
    /**
     * 计划工期天数
     */
    public java.math.BigDecimal getPlanDay() {
        return planDay;
    }

    /**
     * 计划工期天数
     */
    public void setPlanDay(java.math.BigDecimal planDay) {
        this.planDay = planDay;
    }
    /**
     * 工程类型
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public Long getEngineeringType() {
        return engineeringType;
    }

    /**
     * 工程类型
     */
    @ReferDeserialTransfer
    public void setEngineeringType(Long engineeringType) {
        this.engineeringType = engineeringType;
    }
    /**
     * 工程类型名称
     */
    public String getEngineeringTypeName() {
        return engineeringTypeName;
    }

    /**
     * 工程类型名称
     */
    public void setEngineeringTypeName(String engineeringTypeName) {
        this.engineeringTypeName = engineeringTypeName;
    }
    /**
     * 招标代理机构
     */
    public String getBiddingAgency() {
        return biddingAgency;
    }

    /**
     * 招标代理机构
     */
    public void setBiddingAgency(String biddingAgency) {
        this.biddingAgency = biddingAgency;
    }
    /**
     * 评审内容
     */
    public String getReviewInfo() {
        return reviewInfo;
    }

    /**
     * 评审内容
     */
    public void setReviewInfo(String reviewInfo) {
        this.reviewInfo = reviewInfo;
    }
    /**
     * 备注信息
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注信息
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织ID
     */
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织ID
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 报名ID
     */
    public Long getEnrollId() {
        return enrollId;
    }

    /**
     * 报名ID
     */
    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }
    /**
     * 是否中止
     */
    public Integer getIsStop() {
        return isStop;
    }

    /**
     * 是否中止
     */
    public void setIsStop(Integer isStop) {
        this.isStop = isStop;
    }
    /**
     * 编制人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 编制人
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 编制人
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 编制人
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 编制日期
     */
    public java.util.Date getBillDate() {
        return billDate;
    }

    /**
     * 编制日期
     */
    public void setBillDate(java.util.Date billDate) {
        this.billDate = billDate;
    }
    /**
     * 编制机构
     */
    @ReferSerialTransfer(referCode="idm-org")
    public Long getMakeOrgId() {
        return makeOrgId;
    }

    /**
     * 编制机构
     */
    @ReferDeserialTransfer
    public void setMakeOrgId(Long makeOrgId) {
        this.makeOrgId = makeOrgId;
    }
    /**
     * 编制机构
     */
    public String getMakeOrgName() {
        return makeOrgName;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgName(String makeOrgName) {
        this.makeOrgName = makeOrgName;
    }
    
}
